#!/usr/bin/perl -w

# test script for Mapivi 
# http://mapivi.sourceforge.net/mapivi.shtml

use strict;
use warnings;
use File::Basename; # for fileparse() etc.

# test if all icons in folder ../icons/ are used in mapivi.pl
# by searching the Perl code of mapivi.pl
# this will fail if an icon file name is mentioned in the code
# but the this line is commented out
check_icons("../icons");



##############################################################
##############################################################
sub check_icons {
  my $dir = shift;
  my @icons = get_files($dir);
  my %icons;
  foreach (@icons) { $icons{$_}++; }
  print "check_icons: dir \"$dir\" found ".scalar(@icons)." icons:\n";
  print "  check_icons: reading mapivi.pl ...\n";
  my @mapivi_lines = read_file("../mapivi.pl");
  print "  check_icons: read mapivi, found ".scalar(@mapivi_lines)." lines:\n";
  print "  check_icons: checking (may need some time) ... \n";
  #my $nr = 0;
  foreach my $line (@mapivi_lines) {
    #print "l = $line\n";
    #$nr++;
    #last if ($nr > 100);
    foreach my $icon (keys %icons) {
      if ($line =~ m|.*$icon.*|) {
        #print "found $icon in $line\n";
        delete $icons{$icon};
        #print scalar(keys(%icons));
      }
    }
  }
  #print "\n";
  foreach my $icon (keys %icons) {
    print "    Warning: icon not found in mapivi.pl: $icon\n";
  }
}
  
##############################################################
# get_files - returns the filelist of the given dir
#            ignores empty files
##############################################################
sub get_files {
  my $dir = shift;
  my @fileDirList = read_dir($dir);
  my @fileList;
  foreach (@fileDirList) {
    # put only files which are not empty into the filelist
    push @fileList, $_ if ((-f "$dir/$_") and (!-z "$dir/$_"));
  }
  return @fileList;
}

##############################################################
# read_dir - reads the contents of the given directory
##############################################################
sub read_dir {
  my $dir = shift;
  my @fileDirList;
  if (! -d $dir) {
    warn "read_dir: $dir is no dir!: $!";
    return @fileDirList;
  }
  # open the directory
  if (!opendir ACTDIR, $dir) {
    warn "Can't open folder $dir: $!";
    return @fileDirList;
  }
  # show no files starting with a '.', but '..'
  @fileDirList = grep /^(\.\.)|^[^\.]+.*$/, readdir ACTDIR;
  closedir ACTDIR;
  return @fileDirList;
}

##############################################################
# read_file
##############################################################
sub read_file {
  my $file = shift;
  my @data;
  return @data if (!-f $file);
  my $fh;
  if (!open($fh, '<', $file)) {
    warn "Could not open file: $!";
	  return @data;
  }
  # read in lines
  @data = <$fh>;
  # close file
  close $fh;
  return @data;
}
